Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(665)

Unified Diff: src/compiler/simplified-lowering.h

Issue 1571263004: [turbofan] Replace MachineSemantic with Type in simplified lowering. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Rename upper -> type Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/representation-change.cc ('k') | src/compiler/simplified-lowering.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/simplified-lowering.h
diff --git a/src/compiler/simplified-lowering.h b/src/compiler/simplified-lowering.h
index c24408c7c2dfbe3d72c3ad3ebba0b83c7fddb25b..d71dcc23b7bbbe098246a442f83adb9c257a4f7f 100644
--- a/src/compiler/simplified-lowering.h
+++ b/src/compiler/simplified-lowering.h
@@ -31,9 +31,9 @@ class SimplifiedLowering final {
void LowerAllNodes();
// TODO(turbofan): The output_type can be removed once the result of the
// representation analysis is stored in the node bounds.
- void DoLoadBuffer(Node* node, MachineType output_type,
+ void DoLoadBuffer(Node* node, MachineRepresentation rep,
RepresentationChanger* changer);
void DoStoreBuffer(Node* node);
void DoObjectIsNumber(Node* node);
@@ -31,9 +31,9 @@ class SimplifiedLowering final {
void LowerAllNodes();
- // TODO(turbofan): The output_type can be removed once the result of the
+ // TODO(turbofan): The representation can be removed once the result of the
// representation analysis is stored in the node bounds.
« no previous file with comments | « src/compiler/representation-change.cc ('k') | src/compiler/simplified-lowering.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698